@@ -1,9 +1,12 @@
 from django.conf import settings
-from django.contrib.auth.models import User
+from django.contrib.auth import get_user_model
 from django.utils.translation import gettext_lazy
 from wagtail.admin.mail import send_mail
 
 
+User = get_user_model()
+
+
 def get_full_url(url):
     if hasattr(settings, "BASE_URL") and url.startswith("/"):
         url = settings.BASE_URL + url
